nvector._core.cross_track_distance — nvector 0.7.5 documentation

# nvector._core.cross_track_distance

`cross_track_distance`(path, n_EB_E, method='greatcircle', radius=6371009.0)

  Returns cross track distance between path A and position B.

  Parameters
    path: tuple of 2 n-vectors

      > 2 n-vectors of positions defining path A, decomposed in E.

      n_EB_E: 3 x m array

        n-vector(s) of position B to measure the cross track distance to.

      method: string

        defining distance calculated. Options are: ‘greatcircle’ or ‘euclidean’

      radius: real scalar

        radius of sphere. (default 6371009.0)

  Returns
    distancearray of length max(n, m)

      cross track distance(s)